@@ -1,3 +1,5 @@
+from typing import Tuple
+
 from django.contrib import admin
 from django.core.exceptions import ObjectDoesNotExist
 from django.template.loader import render_to_string
@@ -53,12 +55,19 @@ class AeFollowupModelAdminMixin(
         "ae_grade": admin.VERTICAL,
     }
 
-    search_fields = [
-        "action_identifier",
-        "ae_initial__tracking_identifier",
-        "ae_initial__subject_identifier",
-        "ae_initial__action_identifier",
-    ]
+    def get_search_fields(self, request) -> Tuple[str, ...]:
+        search_fields = super().get_search_fields(request)
+        return tuple(
+            set(
+                search_fields
+                + (
+                    "action_identifier",
+                    "ae_initial__tracking_identifier",
+                    "ae_initial__subject_identifier",
+                    "ae_initial__action_identifier",
+                )
+            )
+        )
 
     def get_list_display(self, request) -> tuple:
         list_display = super().get_list_display(request)
